summaryrefslogtreecommitdiffstats
path: root/base/file_util_proxy.h
diff options
context:
space:
mode:
Diffstat (limited to 'base/file_util_proxy.h')
-rw-r--r--base/file_util_proxy.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/base/file_util_proxy.h b/base/file_util_proxy.h
index 32b78630..e716ab7 100644
--- a/base/file_util_proxy.h
+++ b/base/file_util_proxy.h
@@ -89,6 +89,7 @@ class FileUtilProxy {
// If destination file doesn't exist or destination's parent
// doesn't exists.
// If source dir exists but destination path is an existing file.
+ // If source file exists but destination path is an existing directory.
// If source is a parent of destination.
// If source doesn't exists.
static bool Copy(scoped_refptr<MessageLoopProxy> message_loop_proxy,
@@ -105,9 +106,11 @@ class FileUtilProxy {
bool recursive,
StatusCallback* callback);
// Deletes a file or empty directory.
static bool Delete(scoped_refptr<MessageLoopProxy> message_loop_proxy,
const FilePath& file_path,
+ bool recursive,
StatusCallback* callback);
// Moves a file or a directory from src_file_path to dest_file_path.
@@ -105,9 +106,11 @@ class FileUtilProxy {
bool recursive,
StatusCallback* callback);
- // Deletes a file or empty directory.
+ // Deletes a file or a directory.
+ // It is an error to delete a non-empty directory with recursive=false.
static bool Delete(scoped_refptr<MessageLoopProxy> message_loop_proxy,
const FilePath& file_path,